Module database

Module database 

Re-exports of the docbox-database crate

Modules

create
Create
migrations
models
pool
Database Pool
sqlx
The async SQL toolkit for Rust, built with ❤️ by the LaunchBadge team.
utils

Structs

DatabasePoolCache
Cache for database pools
DatabasePoolCacheConfig
Config for the database pool
DbSecrets
Username and password for a specific database
PgConnectOptions
Options and flags which can be used to configure a PostgreSQL connection.
Postgres
PostgreSQL database driver.
Transaction
An in-progress database transaction or savepoint.

Enums

DatabasePoolCacheConfigError
DbConnectErr

Constants

ROOT_DATABASE_NAME
Name of the root database
ROOT_DATABASE_ROLE_NAME
Name of the root database role

Traits

DbExecutor
An alias for Executor<'_, Database = Postgres>.

Type Aliases

DbErr
Short type alias for a database error
DbPool
Type of the database connection pool
DbResult
Type alias for a result where the error is a DbErr
DbTransaction
Type of a database transaction
PgPool
An alias for Pool, specialized for Postgres.
PgPoolOptions
An alias for PoolOptions, specialized for Postgres.