create_database

Function create_database 

pub async fn create_database(
    db: &Pool<Postgres>,
    db_name: &str,
) -> Result<(), Error>
Creates a new database.

Running this requires using an account with a higher level of access than the standard db user