pub struct DocumentBox {
pub scope: String,
pub created_at: DateTime<Utc>,
}Fields
scope: StringScope for the document box
created_at: DateTime<Utc>Date of creation for the document box
Implementations
Sourceimpl DocumentBox
impl DocumentBox
Sourcepub async fn query(
db: impl PgExecutor<'_>,
offset: u64,
limit: u64,
) -> Result<Vec<DocumentBox>, Error>
pub async fn query( db: impl PgExecutor<'_>, offset: u64, limit: u64, ) -> Result<Vec<DocumentBox>, Error>
Get a page from the document boxes list
Sourcepub async fn total(db: impl PgExecutor<'_>) -> Result<i64, Error>
pub async fn total(db: impl PgExecutor<'_>) -> Result<i64, Error>
Get the total number of document boxes in the tenant
Sourcepub async fn search_query(
db: impl PgExecutor<'_>,
query: &str,
offset: u64,
limit: u64,
) -> Result<Vec<DocumentBox>, Error>
pub async fn search_query( db: impl PgExecutor<'_>, query: &str, offset: u64, limit: u64, ) -> Result<Vec<DocumentBox>, Error>
Get a page from the document boxes list based on a search query
Sourcepub async fn search_total(
db: impl PgExecutor<'_>,
query: &str,
) -> Result<i64, Error>
pub async fn search_total( db: impl PgExecutor<'_>, query: &str, ) -> Result<i64, Error>
Get the total number of document boxes in the tenant for the specific search query
Sourcepub async fn find_by_scope(
db: impl PgExecutor<'_>,
scope: &str,
) -> Result<Option<DocumentBox>, Error>
pub async fn find_by_scope( db: impl PgExecutor<'_>, scope: &str, ) -> Result<Option<DocumentBox>, Error>
Find a specific document box by scope within a tenant
Sourcepub async fn create(
db: impl PgExecutor<'_>,
scope: String,
) -> Result<DocumentBox, Error>
pub async fn create( db: impl PgExecutor<'_>, scope: String, ) -> Result<DocumentBox, Error>
Creates a document box with the provided scope
Sourcepub async fn delete(
&self,
db: impl PgExecutor<'_>,
) -> Result<PgQueryResult, Error>
pub async fn delete( &self, db: impl PgExecutor<'_>, ) -> Result<PgQueryResult, Error>
Deletes the document box