pub struct Folder {
pub id: Uuid,
pub name: String,
pub pinned: bool,
pub document_box: String,
pub folder_id: Option<Uuid>,
pub created_at: DateTime<Utc>,
pub created_by: Option<String>,
}Fields
id: UuidUnique identifier for the folder
name: StringName of the file
pinned: boolWhether the folder is marked as pinned
document_box: StringID of the document box the folder belongs to
folder_id: Option<Uuid>Parent folder ID if the folder is a child
created_at: DateTime<Utc>When the folder was created
created_by: Option<String>User who created the folder
Implementations
Sourceimpl Folder
impl Folder
pub async fn create( db: impl PgExecutor<'_>, __arg1: CreateFolder, ) -> Result<Folder, Error>
Sourcepub async fn tree_all_children(
&self,
db: impl PgExecutor<'_>,
) -> Result<Vec<Uuid>, Error>
pub async fn tree_all_children( &self, db: impl PgExecutor<'_>, ) -> Result<Vec<Uuid>, Error>
Collects the IDs of all child folders within the current folder
Results are passed to the search engine when searching within a specific folder to only get results from the folder subtree
Sourcepub async fn count_children(
db: impl PgExecutor<'_>,
folder_id: Uuid,
) -> Result<FolderChildrenCount, Error>
pub async fn count_children( db: impl PgExecutor<'_>, folder_id: Uuid, ) -> Result<FolderChildrenCount, Error>
Uses a recursive query to count all the children in the provided folder
Sourcepub async fn resolve_path(
db: impl PgExecutor<'_>,
folder_id: Uuid,
) -> Result<Vec<FolderPathSegment>, Error>
pub async fn resolve_path( db: impl PgExecutor<'_>, folder_id: Uuid, ) -> Result<Vec<FolderPathSegment>, Error>
Collects the IDs and names of all parent folders of the provided folder
pub async fn move_to_folder( self, db: impl PgExecutor<'_>, folder_id: Uuid, ) -> Result<Folder, Error>
pub async fn rename( self, db: impl PgExecutor<'_>, name: String, ) -> Result<Folder, Error>
pub async fn set_pinned( self, db: impl PgExecutor<'_>, pinned: bool, ) -> Result<Folder, Error>
pub async fn find_by_id( db: impl PgExecutor<'_>, scope: &String, id: Uuid, ) -> Result<Option<Folder>, Error>
Sourcepub async fn all_non_root(
db: impl PgExecutor<'_>,
offset: u64,
page_size: u64,
) -> Result<Vec<Folder>, Error>
pub async fn all_non_root( db: impl PgExecutor<'_>, offset: u64, page_size: u64, ) -> Result<Vec<Folder>, Error>
Get all folders and sub folder across any scope in a paginated fashion (Ignores roots of document boxes)
pub async fn find_by_parent( db: impl PgExecutor<'_>, parent_id: Uuid, ) -> Result<Vec<Folder>, Error>
pub async fn find_root( db: impl PgExecutor<'_>, document_box: &String, ) -> Result<Option<Folder>, Error>
Sourcepub async fn delete(
&self,
db: impl PgExecutor<'_>,
) -> Result<PgQueryResult, Error>
pub async fn delete( &self, db: impl PgExecutor<'_>, ) -> Result<PgQueryResult, Error>
Deletes the folder
Sourcepub async fn resolve_with_extra_mixed_scopes(
db: impl PgExecutor<'_>,
folders_scope_with_id: Vec<DocboxInputPair<'_>>,
) -> Result<Vec<WithFullPath<FolderWithExtra>>, Error>
pub async fn resolve_with_extra_mixed_scopes( db: impl PgExecutor<'_>, folders_scope_with_id: Vec<DocboxInputPair<'_>>, ) -> Result<Vec<WithFullPath<FolderWithExtra>>, Error>
Finds a collection of folders that are in various document box scopes, resolves both the folders themselves and the folder path to traverse to get to each folder
Sourcepub async fn resolve_with_extra(
db: impl PgExecutor<'_>,
scope: &String,
folder_ids: Vec<Uuid>,
) -> Result<Vec<WithFullPath<FolderWithExtra>>, Error>
pub async fn resolve_with_extra( db: impl PgExecutor<'_>, scope: &String, folder_ids: Vec<Uuid>, ) -> Result<Vec<WithFullPath<FolderWithExtra>>, Error>
Finds a collection of folders that are all within the same document box, resolves both the folders themselves and the folder path to traverse to get to each folder
pub async fn find_by_id_with_extra( db: impl PgExecutor<'_>, scope: &String, id: Uuid, ) -> Result<Option<WithFullPath<FolderWithExtra>>, Error>
pub async fn find_by_parent_with_extra( db: impl PgExecutor<'_>, parent_id: Uuid, ) -> Result<Vec<FolderWithExtra>, Error>
pub async fn find_root_with_extra( db: impl PgExecutor<'_>, document_box: &String, ) -> Result<Option<WithFullPath<FolderWithExtra>>, Error>
Sourcepub async fn total_count(db: impl PgExecutor<'_>) -> Result<i64, Error>
pub async fn total_count(db: impl PgExecutor<'_>) -> Result<i64, Error>
Get the total number of folders in the tenant