pub struct GeneratedFile {
pub id: Uuid,
pub file_id: Uuid,
pub mime: String,
pub ty: GeneratedFileType,
pub hash: String,
pub file_key: String,
pub created_at: DateTime<Utc>,
}Expand description
File generated as an artifact of an uploaded file
Fields
id: UuidUnique identifier for the file
file_id: UuidFile this generated file belongs to
mime: StringMime type of the generated file content
ty: GeneratedFileTypeType of the generated file
hash: StringHash of the file this was generated from
file_key: StringS3 key pointing to the file
created_at: DateTime<Utc>When the file was created
Implementations
Sourceimpl GeneratedFile
impl GeneratedFile
pub async fn create( db: impl PgExecutor<'_>, __arg1: CreateGeneratedFile, ) -> Result<GeneratedFile, Error>
Sourcepub async fn delete(
self,
db: impl PgExecutor<'_>,
) -> Result<PgQueryResult, Error>
pub async fn delete( self, db: impl PgExecutor<'_>, ) -> Result<PgQueryResult, Error>
Deletes the generated file
pub async fn find_all( db: impl PgExecutor<'_>, file_id: Uuid, ) -> Result<Vec<GeneratedFile>, Error>
Sourcepub async fn find(
db: impl PgExecutor<'_>,
scope: &String,
file_id: Uuid,
ty: GeneratedFileType,
) -> Result<Option<GeneratedFile>, Error>
pub async fn find( db: impl PgExecutor<'_>, scope: &String, file_id: Uuid, ty: GeneratedFileType, ) -> Result<Option<GeneratedFile>, Error>
Finds a specific file using its full path scope -> folder -> file