pub struct LinkResolvedMetadata {
pub url: String,
pub metadata: StoredResolvedWebsiteMetadata,
pub expires_at: DateTime<Utc>,
}Fields
url: StringURL of the resolved metadata
metadata: StoredResolvedWebsiteMetadataThe metadata itself
expires_at: DateTime<Utc>Timestamp of when the metadata will expire
Implementations
Sourceimpl LinkResolvedMetadata
impl LinkResolvedMetadata
Sourcepub async fn create(
db: impl PgExecutor<'_>,
create: CreateLinkResolvedMetadata,
) -> Result<(), Error>
pub async fn create( db: impl PgExecutor<'_>, create: CreateLinkResolvedMetadata, ) -> Result<(), Error>
Create and insert a new resolved link metadata
Sourcepub async fn query(
db: impl PgExecutor<'_>,
url: &str,
) -> Result<Option<LinkResolvedMetadata>, Error>
pub async fn query( db: impl PgExecutor<'_>, url: &str, ) -> Result<Option<LinkResolvedMetadata>, Error>
Query the resolved link metadata for the provided URL
Sourcepub async fn delete_expired(
db: impl PgExecutor<'_>,
before: DateTime<Utc>,
) -> Result<PgQueryResult, Error>
pub async fn delete_expired( db: impl PgExecutor<'_>, before: DateTime<Utc>, ) -> Result<PgQueryResult, Error>
Deletes all metadata where the expiry date is less than before