pub struct DocboxSearchMatchRanked {
pub search_match: DocboxSearchMatch,
pub rank: f64,
pub total_count: i64,
}Fields
search_match: DocboxSearchMatchrank: f64total_count: i64Trait Implementations
Sourceimpl Clone for DocboxSearchMatchRanked
impl Clone for DocboxSearchMatchRanked
Sourcefn clone(&self) -> DocboxSearchMatchRanked
fn clone(&self) -> DocboxSearchMatchRanked
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DocboxSearchMatchRanked
impl Debug for DocboxSearchMatchRanked
Sourceimpl<'r> Decode<'r, Postgres> for DocboxSearchMatchRanked
impl<'r> Decode<'r, Postgres> for DocboxSearchMatchRanked
Sourcefn decode(
value: PgValueRef<'r>,
) -> Result<DocboxSearchMatchRanked, Box<dyn Error + Sync + Send>>
fn decode( value: PgValueRef<'r>, ) -> Result<DocboxSearchMatchRanked, Box<dyn Error + Sync + Send>>
Decode a new value of this type using a raw value from the database.
Sourceimpl<'de> Deserialize<'de> for DocboxSearchMatchRanked
impl<'de> Deserialize<'de> for DocboxSearchMatchRanked
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<DocboxSearchMatchRanked, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<DocboxSearchMatchRanked, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<'q> Encode<'_, Postgres> for DocboxSearchMatchRanked
impl<'q> Encode<'_, Postgres> for DocboxSearchMatchRanked
Sourcefn encode_by_ref(
&self,
buf: &mut PgArgumentBuffer,
) -> Result<IsNull, Box<dyn Error + Sync + Send>>
fn encode_by_ref( &self, buf: &mut PgArgumentBuffer, ) -> Result<IsNull, Box<dyn Error + Sync + Send>>
fn size_hint(&self) -> usize
Sourcefn encode(
self,
buf: &mut <DB as Database>::ArgumentBuffer<'q>,
) -> Result<IsNull, Box<dyn Error + Sync + Send>>where
Self: Sized,
fn encode(
self,
buf: &mut <DB as Database>::ArgumentBuffer<'q>,
) -> Result<IsNull, Box<dyn Error + Sync + Send>>where
Self: Sized,
Writes the value of
self into buf in the expected format for the database.fn produces(&self) -> Option<<DB as Database>::TypeInfo>
Sourceimpl From<DocboxSearchMatchRanked> for FlattenedItemResult
impl From<DocboxSearchMatchRanked> for FlattenedItemResult
Sourcefn from(value: DocboxSearchMatchRanked) -> FlattenedItemResult
fn from(value: DocboxSearchMatchRanked) -> FlattenedItemResult
Converts to this type from the input type.
Sourceimpl<'a, R> FromRow<'a, R> for DocboxSearchMatchRanked
impl<'a, R> FromRow<'a, R> for DocboxSearchMatchRanked
Sourceimpl PgHasArrayType for DocboxSearchMatchRanked
impl PgHasArrayType for DocboxSearchMatchRanked
fn array_type_info() -> PgTypeInfo
fn array_compatible(ty: &PgTypeInfo) -> bool
Sourceimpl Serialize for DocboxSearchMatchRanked
impl Serialize for DocboxSearchMatchRanked
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more