pub struct DocboxSearchPageMatch {
pub page: i64,
pub matched: String,
pub content_match_rank: f64,
pub total_hits: i64,
}Fields
page: i64matched: Stringcontent_match_rank: f64total_hits: i64Trait Implementations
Sourceimpl Clone for DocboxSearchPageMatch
impl Clone for DocboxSearchPageMatch
Sourcefn clone(&self) -> DocboxSearchPageMatch
fn clone(&self) -> DocboxSearchPageMatch
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DocboxSearchPageMatch
impl Debug for DocboxSearchPageMatch
Sourceimpl<'r> Decode<'r, Postgres> for DocboxSearchPageMatch
impl<'r> Decode<'r, Postgres> for DocboxSearchPageMatch
Sourcefn decode(
value: PgValueRef<'r>,
) -> Result<DocboxSearchPageMatch, Box<dyn Error + Sync + Send>>
fn decode( value: PgValueRef<'r>, ) -> Result<DocboxSearchPageMatch, Box<dyn Error + Sync + Send>>
Decode a new value of this type using a raw value from the database.
Sourceimpl<'de> Deserialize<'de> for DocboxSearchPageMatch
impl<'de> Deserialize<'de> for DocboxSearchPageMatch
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<DocboxSearchPageMatch, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<DocboxSearchPageMatch, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<'q> Encode<'_, Postgres> for DocboxSearchPageMatch
impl<'q> Encode<'_, Postgres> for DocboxSearchPageMatch
Sourcefn encode_by_ref(
&self,
buf: &mut PgArgumentBuffer,
) -> Result<IsNull, Box<dyn Error + Sync + Send>>
fn encode_by_ref( &self, buf: &mut PgArgumentBuffer, ) -> Result<IsNull, Box<dyn Error + Sync + Send>>
fn size_hint(&self) -> usize
Sourcefn encode(
self,
buf: &mut <DB as Database>::ArgumentBuffer<'q>,
) -> Result<IsNull, Box<dyn Error + Sync + Send>>where
Self: Sized,
fn encode(
self,
buf: &mut <DB as Database>::ArgumentBuffer<'q>,
) -> Result<IsNull, Box<dyn Error + Sync + Send>>where
Self: Sized,
Writes the value of
self into buf in the expected format for the database.fn produces(&self) -> Option<<DB as Database>::TypeInfo>
Sourceimpl From<DocboxSearchPageMatch> for PageResult
impl From<DocboxSearchPageMatch> for PageResult
Sourcefn from(value: DocboxSearchPageMatch) -> PageResult
fn from(value: DocboxSearchPageMatch) -> PageResult
Converts to this type from the input type.
Sourceimpl<'a, R> FromRow<'a, R> for DocboxSearchPageMatch
impl<'a, R> FromRow<'a, R> for DocboxSearchPageMatch
Sourceimpl PgHasArrayType for DocboxSearchPageMatch
impl PgHasArrayType for DocboxSearchPageMatch
fn array_type_info() -> PgTypeInfo
fn array_compatible(ty: &PgTypeInfo) -> bool
Sourceimpl Serialize for DocboxSearchPageMatch
impl Serialize for DocboxSearchPageMatch
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more