pub struct Task {
pub id: Uuid,
pub document_box: String,
pub status: TaskStatus,
pub output_data: Option<Value>,
pub created_at: DateTime<Utc>,
pub completed_at: Option<DateTime<Utc>>,
}Expand description
Represents a stored asynchronous task progress
Fields
id: UuidUnique ID of the task
document_box: StringID of the document box the task belongs to
status: TaskStatusStatus of the task
output_data: Option<Value>Output data from the task completion
created_at: DateTime<Utc>When the task was created
completed_at: Option<DateTime<Utc>>Implementations
Sourceimpl Task
impl Task
Sourcepub async fn create(
db: impl PgExecutor<'_>,
document_box: String,
) -> Result<Task, Error>
pub async fn create( db: impl PgExecutor<'_>, document_box: String, ) -> Result<Task, Error>
Stores / updates the stored user data, returns back the user ID
pub async fn find( db: impl PgExecutor<'_>, id: Uuid, document_box: &str, ) -> Result<Option<Task>, Error>
Sourcepub async fn complete_task(
&mut self,
db: impl PgExecutor<'_>,
status: TaskStatus,
output_data: Option<Value>,
) -> Result<(), Error>
pub async fn complete_task( &mut self, db: impl PgExecutor<'_>, status: TaskStatus, output_data: Option<Value>, ) -> Result<(), Error>
Mark the task as completed and set its output data
Sourcepub async fn delete_expired(
db: impl PgExecutor<'_>,
before: DateTime<Utc>,
) -> Result<PgQueryResult, Error>
pub async fn delete_expired( db: impl PgExecutor<'_>, before: DateTime<Utc>, ) -> Result<PgQueryResult, Error>
Deletes all tasks where the creation date is older than the before date