Events
Event publishing abstraction
- EventPublisherFactory Factory for building a publisher based on the tenant
- SqsEventPublisherFactory SQS based event notifications
- NoopEventPublisher No-op publishing for tenants without event targets
- [MpscEventPublisher] In memory channel publisher for tests
Modules
Structs
Enums
- Tenant
Event Message - Event inner message type, containing the actual event data
- Tenant
Event Publisher - Dynamic event publisher for a tenant
Traits
- Event
Publisher - Abstraction providing the ability to publish an event