Module folder_stream

Module folder_stream 

Structs

FolderWalkStream
Stream for walking a folder starting with a top most folder producing each of the folders children walking depth first

Enums

FolderWalkError
Error that can occur when walking the folder
FolderWalkItem
Item produced by FolderWalkStream