Module process

Module process 

Processing

Logic for processing notifications from the notification queue

Structs

NotificationQueueData

Functions

handle_file_uploaded
Handle file upload notifications
handle_file_uploaded_tenant
Handle file upload notification once the tenant has been identified
process_notification_queue
Processes events coming from the notification queue. This will be things like successful file uploads that need to be processed