pub struct SearchIndexData {
pub ty: SearchIndexType,
pub folder_id: Uuid,
pub document_box: String,
pub item_id: Uuid,
pub name: String,
pub mime: Option<String>,
pub content: Option<String>,
pub created_at: DateTime<Utc>,
pub created_by: Option<String>,
pub pages: Option<Vec<DocumentPage>>,
}Fields
ty: SearchIndexTypeType of item the search index data is representing
folder_id: UuidID of the folder the indexed item is within.
(For searching only withing a specific folder path)
document_box: StringDocument box scope that this item is within
(For restricting search scope)
item_id: UuidUnique ID for the actual document
this is to allow multiple page documents to be stored as separate search index items without overriding each other
name: StringName of this item
mime: Option<String>Mime type when working with file items (Otherwise none)
content: Option<String>For files this is the file content (With an associated page number) For links this is the link value
created_at: DateTime<Utc>Creation date for the item
created_by: Option<String>User who created the item
pages: Option<Vec<DocumentPage>>Optional pages of document content