Module storage

Module storage 

Re-exports of the docbox-storage crate

Modules

s3
S3 Storage Backend

Structs

FileStream
Stream of bytes from a file

Enums

CreateBucketOutcome
Outcome from creating a bucket
StorageLayerError
Errors that can occur when using a storage layer
StorageLayerFactory
Storage layer factory for creating storage layer instances with some underlying backend implementation
StorageLayerFactoryConfig
Configuration for a storage layer factory
StorageLayerFactoryConfigError
Errors that could occur when loading the storage layer factory configuration from the environment
TenantStorageLayer
Storage layer for a tenant with different underlying backends