Tenant Cache
Provides caching for tenants to ensure we don’t have to fetch the tenant from the database for every request
Structs
- Tenant
Cache - Cache for recently used tenants
Provides caching for tenants to ensure we don’t have to fetch the tenant from the database for every request