Module web_scraper

Module web_scraper 

Re-exports of the docbox-web-scraper crate

Structs

Favicon
Favicon extracted from a website
ResolvedImage
Represents an image that has been resolved where the contents are now know and the content type as well
ResolvedWebsiteMetadata
Metadata resolved from a scraped website
Url
A parsed URL record.
WebsiteMetaService
Service for looking up website metadata and storing a cached value
WebsiteMetaServiceConfig
Configuration for the website metadata service

Enums

WebsiteMetaServiceConfigError
Errors that could occur when loading the configuration