pub struct ResolvedImage {
pub content_type: Mime,
pub stream: ImageStream,
}Expand description
Represents an image that has been resolved where the contents are now know and the content type as well
Fields
content_type: MimeContent type of the image
stream: ImageStreamStream for the image bytes