HttpError

Trait HttpError 

pub trait HttpError:
    Error
    + Send
    + Sync
    + 'static {
    // Provided methods
    fn status(&self) -> StatusCode { ... }
    fn reason(&self) -> String { ... }
    fn type_name(&self) -> &str { ... }
}
Trait implemented by errors that can be converted into HttpErrors and used as error responses

Provided Methods

fn status(&self) -> StatusCode

Provides the HTTP StatusCode to use when creating this error response

fn reason(&self) -> String

Provides the reason message to use in the error response

fn type_name(&self) -> &str

Provides the full type name for the actual error type thats been erased by dynamic typing (For better error source clarity)

Implementations on Foreign Types

Source

impl HttpError for Error

Source

impl HttpError for InvalidHeaderValue

Implementors