Module middleware

Module middleware 

Modules

action_user
Extractor for getting the user details from the headers set by the API
api_key
tenant
Extractor for extracting the current tenant from the API headers