Extractor for getting the user details from the headers set by the API
Structs
- Action
User - Action
User Data - User
Params - OpenAPI param for optional the user identifying headers
Extractor for getting the user details from the headers set by the API