pub struct UserParams {
pub user_id: Option<String>,
pub user_name: Option<String>,
pub user_image_id: Option<String>,
}Expand description
OpenAPI param for optional the user identifying headers
Fields
user_id: Option<String>Optional ID of the user if performed on behalf of a user
user_name: Option<String>Optional name of the user if performed on behalf of a user
user_image_id: Option<String>Optional image ID of the user if performed on behalf of a user