Module tenant

Module tenant 

Extractor for extracting the current tenant from the API headers

Structs

TenantDb
Extractor to get database access for the current tenant
TenantEvents
Tenant events access
TenantParams
OpenAPI param for requiring the tenant identifier headers
TenantSearch
Tenant open search instance
TenantStorage
Tenant storage access

Enums

ExtractTenantError

Constants

TENANT_ENV_HEADER
TENANT_ID_HEADER

Functions

extract_tenant
Extracts the target tenant for the provided request
get_tenant_env
tenant_auth_middleware
Authenticates the requested tenant, loads the tenant from the database and stores it on the request extensions so it can be extracted by handlers