Module file

Module file 

Structs

BinaryResponse
Type hint type for Utoipa to indicate a binary response type
CreatePresignedRequest
Request to create a new presigned file upload
FileResponse
Response for requesting a document box
GetPresignedRequest
Request to rename and or move a file
PresignedDownloadResponse
PresignedUploadResponse
Response describing how to upload the presigned file and the ID for polling the progress
RawFileQuery
UpdateFileRequest
Request to rename and or move a file
UploadFileRequest
UploadTaskResponse
Response from creating an upload
UploadedFile

Enums

FileUploadResponse
HttpFileError
PresignedStatusResponse