CreatePresignedRequest

Struct CreatePresignedRequest 

pub struct CreatePresignedRequest {
    pub name: String,
    pub folder_id: FolderId,
    pub size: i32,
    pub mime: Option<Mime>,
    pub parent_id: Option<FileId>,
    pub processing_config: Option<ProcessingConfig>,
    pub disable_mime_sniffing: Option<bool>,
}
Request to create a new presigned file upload

Fields

name: String

Name of the file being uploaded

folder_id: FolderId

ID of the folder to store the file in

size: i32

Size of the file being uploaded in bytes. Must match the size of the file being uploaded

mime: Option<Mime>

Mime type of the file

parent_id: Option<FileId>

Optional ID of the parent file if this file is associated as a child of another file. Mainly used to associating attachments to email files

processing_config: Option<ProcessingConfig>

Optional processing config

disable_mime_sniffing: Option<bool>

Whether to disable mime sniffing for the file. When false/not specified if a application/octet-stream mime type is provided the file name will be used to attempt to determine the real mime type