pub struct UploadFileRequest {
pub name: String,
pub folder_id: FolderId,
pub file: FieldData<Bytes>,
pub mime: Option<String>,
pub asynchronous: Option<bool>,
pub disable_mime_sniffing: Option<bool>,
pub fixed_id: Option<FileId>,
pub parent_id: Option<FileId>,
pub processing_config: Option<String>,
}Fields
name: StringName of the file being uploaded
folder_id: FolderIdID of the folder to store the file in
file: FieldData<Bytes>The actual file you are uploading, ensure the mime type for the file is set correctly
mime: Option<String>Optional mime type override, when not present the mime type will be extracted from UploadFileRequest::file
asynchronous: Option<bool>Whether to process the file asynchronously returning a task response instead of waiting for the upload
disable_mime_sniffing: Option<bool>Whether to disable mime sniffing for the file. When false/not specified if a application/octet-stream mime type is provided the file name will be used to attempt to determine the real mime type
fixed_id: Option<FileId>Fixed file ID the file must use. Should only be used for migrating existing files and maintaining the same UUID.
Should not be provided for general use
parent_id: Option<FileId>Optional ID of the parent file if this file is associated as a child of another file. Mainly used to associating attachments to email files
processing_config: Option<String>Optional JSON encoded processing config