pub async fn delete_user(
__arg0: TenantDb,
__arg1: Path<String>,
) -> HttpStatusResultExpand description
Delete User
Delete a user by ID, the user must not be associated with any resources (Edit history or creation of resources)
pub async fn delete_user(
__arg0: TenantDb,
__arg1: Path<String>,
) -> HttpStatusResultDelete User
Delete a user by ID, the user must not be associated with any resources (Edit history or creation of resources)