flush_tenant_cache

Function flush_tenant_cache 

pub async fn flush_tenant_cache(
    __arg0: Extension<Arc<TenantCache>>,
) -> HttpStatusResult
Flush tenant cache

Clears the tenant cache, you can use this endpoint if you’ve updated the tenant configuration and want it to be applied immediately without restarting the server