tenant_boxes

Function tenant_boxes 

pub async fn tenant_boxes(
    __arg0: TenantDb,
    __arg1: Garde<Json<TenantDocumentBoxesRequest>>,
) -> HttpResult<TenantDocumentBoxesResponse>
Admin Boxes

Requests a list of document boxes within the tenant optionally filtered to a specific query with support for wildcards