get

Function get 

pub async fn get(
    __arg0: TenantDb,
    __arg1: Path<DocumentBoxScope>,
) -> HttpResult<DocumentBoxResponse>
Get document box by scope

Gets a specific document box and the root folder for the box along with the resolved root folder children