pub async fn get(
__arg0: TenantDb,
__arg1: Path<(DocumentBoxScope, FileId)>,
) -> HttpResult<FileResponse>Expand description
Get file by ID
Gets a specific file details, metadata and associated generated files
pub async fn get(
__arg0: TenantDb,
__arg1: Path<(DocumentBoxScope, FileId)>,
) -> HttpResult<FileResponse>Get file by ID
Gets a specific file details, metadata and associated generated files