get_generated

Function get_generated 

pub async fn get_generated(
    __arg0: TenantDb,
    __arg1: Path<(DocumentBoxScope, FileId, GeneratedFileType)>,
) -> HttpResult<GeneratedFile>
Get generated file

Requests metadata about a specific generated file type for a file, will return the details about the generated file if it exists