get_image

Function get_image 

pub async fn get_image(
    __arg0: TenantDb,
    __arg1: Extension<Arc<ResolveWebsiteService>>,
    __arg2: Path<(DocumentBoxScope, LinkId)>,
) -> Result<Response<Body>, DynHttpError>
Get link social image

Obtain the “Social Image” for the website, this resolves the website metadata and finds the OGP metadata image responding with the image directly. The image data is streamed directly from the target website