pub async fn get(
__arg0: TenantDb,
__arg1: Path<(DocumentBoxScope, TaskId)>,
) -> HttpResult<Task>Expand description
Get task by ID
Get the details about a specific task, used to poll the current progress of a task
pub async fn get(
__arg0: TenantDb,
__arg1: Path<(DocumentBoxScope, TaskId)>,
) -> HttpResult<Task>Get task by ID
Get the details about a specific task, used to poll the current progress of a task