pub async fn delete_database( db: &Pool<Postgres>, db_name: &str, ) -> Result<(), Error>
Delete a database.
Running this requires using an account with a higher level of access than the standard db user