Processing
Logic for processing notifications from the notification queue
Structs
Functions
- handle_
file_ uploaded - Handle file upload notifications
- handle_
file_ uploaded_ tenant - Handle file upload notification once the tenant has been identified
- process_
notification_ queue - Processes events coming from the notification queue. This will be things like successful file uploads that need to be processed