pub struct WebsiteMetaServiceConfig {
pub http_proxy: Option<String>,
pub https_proxy: Option<String>,
pub metadata_connect_timeout: Duration,
pub metadata_read_timeout: Duration,
}Expand description
Configuration for the website metadata service
Fields
http_proxy: Option<String>HTTP proxy to use when making HTTP metadata requests
https_proxy: Option<String>HTTPS proxy to use when making HTTPS metadata requests
metadata_connect_timeout: DurationTime to wait when attempting to fetch resource before timing out
This option is ignored if you manually provide a reqwest::Client
Default: 5s
metadata_read_timeout: DurationTime to wait while downloading a resource before timing out (between each read of data)
This option is ignored if you manually provide a reqwest::Client
Default: 10s
Implementations
Sourceimpl WebsiteMetaServiceConfig
impl WebsiteMetaServiceConfig
Sourcepub fn from_env() -> Result<WebsiteMetaServiceConfig, WebsiteMetaServiceConfigError>
pub fn from_env() -> Result<WebsiteMetaServiceConfig, WebsiteMetaServiceConfigError>
Load a website meta service config from its environment variables