Extractor for extracting the current tenant from the API headers
Structs
- Tenant
Db - Extractor to get database access for the current tenant
- Tenant
Events - Tenant events access
- Tenant
Params - OpenAPI param for requiring the tenant identifier headers
- Tenant
Search - Tenant open search instance
- Tenant
Storage - Tenant storage access
Enums
Constants
Functions
- extract_
tenant - Extracts the target tenant for the provided request
- get_
tenant_ env - tenant_
auth_ middleware - Authenticates the requested tenant, loads the tenant from the database and stores it on the request extensions so it can be extracted by handlers