pub struct ZipFolderRequest {
pub include: Option<Vec<Uuid>>,
pub exclude: Option<Vec<Uuid>>,
}Expand description
Request to create a zip file of folder contents
Fields
include: Option<Vec<Uuid>>Optionally only include the specified items (files and folders)
Inclusion is only applied to the direct descendants of the folder use exclude to exclude specific content from nested folders
exclude: Option<Vec<Uuid>>Optionally exclude the specified items (files and folders) including any items that don’t match the provided list of IDs
Exclusion is applied deeply to nested files and folders