pub async fn flush_database_pool_cache(
__arg0: Extension<Arc<DatabasePoolCache>>,
) -> HttpStatusResultExpand description
Flush database cache
Empties all the database pool and credentials caches, you can use this endpoint if you rotate your database credentials to refresh the database pool without needing to restart the server