pub async fn delete(
__arg0: TenantDb,
__arg1: TenantSearch,
__arg2: TenantStorage,
__arg3: TenantEvents,
__arg4: Path<DocumentBoxScope>,
) -> HttpStatusResultExpand description
Delete document box by scope
Deletes a specific document box by scope and all its contents
Access control for this should probably be restricted on other end to prevent users from deleting an entire bucket?