pub async fn create_presigned(
action_user: ActionUser,
__arg1: Extension<MaxFileSizeBytes>,
__arg2: TenantDb,
__arg3: TenantStorage,
__arg4: Path<DocumentBoxScope>,
__arg5: Garde<Json<CreatePresignedRequest>>,
) -> Result<(StatusCode, Json<PresignedUploadResponse>), DynHttpError>Expand description
Create presigned file upload
Creates a new “presigned” upload, where the file is uploaded directly to storage and processed asynchronously.
Use the task ID from the response to poll the file processing progress.