pub async fn upload(
action_user: ActionUser,
__arg1: TenantDb,
__arg2: TenantSearch,
__arg3: TenantStorage,
__arg4: TenantEvents,
__arg5: Extension<ProcessingLayer>,
__arg6: Path<DocumentBoxScope>,
__arg7: Garde<TypedMultipart<UploadFileRequest>>,
) -> HttpResult<FileUploadResponse>Expand description
Upload file
Uploads a new document to the provided document box folder.
If the asynchronous option is specified a task will be returned otherwise the completed file upload will be returned directly
In a browser environment its recommend to use the async option to prevent running into browser timeouts if the processing takes too long.
In a reverse proxy + browser situation prefer using the presigned file upload endpoint otherwise browsers may timeout while your server transfers the file
Synchronous uploads return UploadedFile Asynchronous uploads return UploadTaskResponse
This endpoint is not available in the serverless version of docbox, instead use the presigned endpoint /box/{scope}/file/presigned