pub async fn delete(
__arg0: TenantDb,
__arg1: TenantStorage,
__arg2: TenantEvents,
__arg3: TenantSearch,
__arg4: Path<(DocumentBoxScope, FolderId)>,
) -> HttpStatusResultExpand description
Delete a folder by ID
Deletes a document box folder and all its contents. This will traverse the folder contents as a stack deleting all files and folders within the folder before deleting itself