pub async fn get(
__arg0: TenantDb,
__arg1: Path<(DocumentBoxScope, FolderId)>,
) -> HttpResult<FolderResponse>Expand description
Get folder by ID
Requests a specific folder by ID. Will return the folder itself as well as the first resolved set of children for the folder